import {IStyleAPI, IStyleItem} from "import-sort-style";

export default function (styleApi: IStyleAPI): IStyleItem[] {
    const {
        and,
        isAbsoluteModule,
        hasNoMember,
        member,
        moduleName,
        name,
        not,
        startsWith,
        unicode,
    } = styleApi;

    function isCss(text: string) {
        return !!text.match(/\.(css|scss)$/);
    }

    return [
        // side-effects with no members or aliases
        {
            match: hasNoMember
        },
        {separator: true},

        // import React from 'react'
        {
            match: and(isAbsoluteModule, moduleName(startsWith('react'))),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {separator: true},

        // next libraries
        {
            match: and(isAbsoluteModule, moduleName(startsWith('next'))),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {separator: true},

        // storybook libraries
        {
            match: and(isAbsoluteModule, moduleName(startsWith('storybook'))),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {
            match: and(isAbsoluteModule, moduleName(startsWith('@storybook'))),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {separator: true},

        // storybook libraries
        {
            match: and(isAbsoluteModule, moduleName(startsWith('material-ui'))),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {
            match: and(isAbsoluteModule, moduleName(startsWith('@material-ui'))),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {separator: true},

        // global libraries
        {
            match: and(isAbsoluteModule, not(moduleName(startsWith('@/')))),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {separator: true},

        // every other import except CSS/SCSS files
        {
            match: not(moduleName(isCss)),
            sort: member(unicode),
            sortNamedMembers: name(unicode)
        },
        {separator: true},
    ];
}
